@@ -8,6 +8,9 @@ except:
 
 def massresize(path, new_width):
     for fname in os.listdir(path):
+        if not os.path.exists(os.path.join(path, "resized")):
+             os.makedirs(os.path.join(path, "resized"))
+        new_fname = os.path.join(path, "resized", fname)
         fname = os.path.join(path, fname)
         try:
             image = Image.open(fname)
@@ -20,4 +23,4 @@ def massresize(path, new_width):
         new_height = int(new_width/(float(width)/height))
 
         new_image = image.resize((new_width, new_height), Image.NEAREST)
-        new_image.save("%s.resized.%s"%(".".join(fname.split(".")[:-1]), fname.split(".")[-1]))
\ No newline at end of file
+        new_image.save(new_fname)
